@@ -34,7 +34,6 @@
 #include <ell/io.h>
 #include <ell/ringbuf.h>
 #include <ell/log.h>
-#include <ell/plugin.h>
 #include <ell/checksum.h>
 #include <ell/settings.h>
 #include <ell/hwdb.h>
@@ -52,10 +51,16 @@
 #include <ell/net.h>
 #include <ell/netlink.h>
 #include <ell/genl.h>
+#include <ell/rtnl.h>
 #include <ell/dbus.h>
 #include <ell/dbus-service.h>
 #include <ell/dbus-client.h>
 #include <ell/dhcp.h>
+#include <ell/dhcp6.h>
+#include <ell/icmp6.h>
 #include <ell/cert.h>
 #include <ell/ecc.h>
 #include <ell/ecdh.h>
+#include <ell/time.h>
+#include <ell/gpio.h>
+#include <ell/path.h>
